lilypondfiletools.ScoreBlock
============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.format

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.is_formatted_when_empty

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.append

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.count

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.extend

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.index

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.insert

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.pop

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.remove

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.reverse

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.sort

   .. note:: Inherited from `__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__add__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__contains__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__delitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__delslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__eq__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__ge__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__getitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__getslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__gt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__iadd__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__imul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__iter__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__le__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__len__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__lt__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__mul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__ne__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__repr__

   .. note:: Inherited from :py:class:`lilypondfiletools._NonattributedBlock <abjad.tools.lilypondfiletools._NonattributedBlock._NonattributedBlock._NonattributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__reversed__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__rmul__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__setitem__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__setslice__

   .. note:: Inherited from `__builtin__.list`

.. automethod:: abjad.tools.lilypondfiletools.ScoreBlock.ScoreBlock.ScoreBlock.__str__

   .. note:: Inherited from `__builtin__.object`
